@@ -1,10 +1,10 @@
 /* Libvisual-plugins - Standard plugins for libvisual
  * 
- * Copyright (C) 2002, 2003, 2004, 2005 Dennis Smit <ds@nerds-incorporated.org>
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006 Dennis Smit <ds@nerds-incorporated.org>
  *
  * Authors: Dennis Smit <ds@nerds-incorporated.org>
  *
- * $Id:
+ * $Id: config.h,v 1.5 2006/01/31 16:42:47 synap Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
@@ -27,11 +27,11 @@
 #include "oinksie.h"
 
 /* random config sets */
-inline void _oink_config_random_blurmode (OinksiePrivate *priv);
-inline void _oink_config_random_scopemode (OinksiePrivate *priv);
-inline void _oink_config_random_backgroundmode (OinksiePrivate *priv);
-inline void _oink_config_random_beatdots (OinksiePrivate *priv);
-inline void _oink_config_random_scopestereo (OinksiePrivate *priv);
-inline void _oink_config_random_palfunky (OinksiePrivate *priv);
+void _oink_config_random_blurmode (OinksiePrivate *priv);
+void _oink_config_random_scopemode (OinksiePrivate *priv);
+void _oink_config_random_backgroundmode (OinksiePrivate *priv);
+void _oink_config_random_beatdots (OinksiePrivate *priv);
+void _oink_config_random_scopestereo (OinksiePrivate *priv);
+void _oink_config_random_palfunky (OinksiePrivate *priv);
 
 #endif /* _OINK_CONFIG_H */
