@@ -1,10 +1,10 @@
 /* Libvisual-plugins - Standard plugins for libvisual
  * 
- * Copyright (C) 2002, 2003, 2004, 2005 Dennis Smit <ds@nerds-incorporated.org>
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006 Dennis Smit <ds@nerds-incorporated.org>
  *
  * Authors: Dennis Smit <ds@nerds-incorporated.org>
  *
- * $Id:
+ * $Id: gfx-scope.h,v 1.6 2006/01/22 13:25:26 synap Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as
@@ -26,9 +26,8 @@
 
 #include "oinksie.h"
 
-void _oink_gfx_scope_balls (OinksiePrivate *priv, uint8_t *buf, int color, int height, int space);
 void _oink_gfx_scope_stereo (OinksiePrivate *priv, uint8_t *buf, int color1, int color2, int height, int space, int rotate);
-void _oink_gfx_scope_bulbous (OinksiePrivate *priv, uint8_t *buf, int color, int height, int mode);
+void _oink_gfx_scope_bulbous (OinksiePrivate *priv, uint8_t *buf, int color, int height);
 void _oink_gfx_scope_normal (OinksiePrivate *priv, uint8_t *buf, int color, int height);
 void _oink_gfx_scope_circle (OinksiePrivate *priv, uint8_t *buf, int color, int size, int x, int y);
 
